Enum googapis::google::cloud::domains::v1beta1::ContactPrivacy [−][src]
#[repr(i32)]
pub enum ContactPrivacy {
Unspecified,
PublicContactData,
PrivateContactData,
RedactedContactData,
}Expand description
Defines a set of possible contact privacy settings for a Registration.
[ICANN](https://icann.org/) maintains the WHOIS database, a publicly
accessible mapping from domain name to contact information, and requires that
each domain name have an entry. Choose from these options to control how much
information in your ContactSettings is published.
Variants
The contact privacy settings are undefined.
All the data from ContactSettings is publicly available. When setting
this option, you must also provide a
PUBLIC_CONTACT_DATA_ACKNOWLEDGEMENT in the contact_notices field of the
request.
None of the data from ContactSettings is publicly available. Instead,
proxy contact data is published for your domain. Email sent to the proxy
email address is forwarded to the registrant’s email address. Cloud Domains
provides this privacy proxy service at no additional cost.
Some data from ContactSettings is publicly available. The actual
information redacted depends on the domain. For details, see the
registration privacy
article.
Implementations